#
# spec file for package go-passbolt-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           go-passbolt-cli
Version:        0.3.1
Release:        3.4
Summary:        A CLI tool to interact with Passbolt
License:        MIT
Group:          Productivity/Security
URL:            https://github.com/passbolt/go-passbolt-cli
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.21

%define bin_name passbolt

%description
This package provides a CLI tool to interact with Passbolt, An Open Source Password Manager for Teams

Passbolt Website: https://www.passbolt.com/

This project is community driven and not associated with Passbolt SA

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       bash-completion
BuildArch:      noarch
Requires:       %{name}
Supplements:    (%{name} and bash-completion)

%description bash-completion
The official bash completion script for %{name}, generated during the build.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Group:          System/Shells
BuildArch:      noarch
Requires:       %{name}
Supplements:    (%{name} and zsh)

%description zsh-completion
The official zsh completion script for %{name}, generated during the build.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
BuildArch:      noarch
Requires:       %{name}
Supplements:    (%{name} and fish)

%description fish-completion
The official fish completion script for %{name}, generated during the build.

%prep
%autosetup -a1

%build
# Renaming the binary, As upsteam prefers to use it in examples
# See: https://github.com/passbolt/go-passbolt-cli?tab=readme-ov-file#getting-started
go build \
   -buildmode=pie \
   -ldflags "-s -w" \
   -o %{bin_name}

# Build the shell autocomplete files
./%{bin_name} completion bash > %{name}-autocomplete.bash
./%{bin_name} completion zsh > %{name}-autocomplete.zsh
./%{bin_name} completion fish > %{name}-autocomplete.fish

# generate man pages
mkdir man && ./%{bin_name} gendoc --type man

%install

# install the binary
install -D -m 0755 %{bin_name} "%{buildroot}%{_bindir}/%{bin_name}"

# Install the shell autocomplete files
install -Dm 644 %{name}-autocomplete.bash %{buildroot}%{_datadir}/bash-completion/completions/%{bin_name}
install -Dm 644 %{name}-autocomplete.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{bin_name}
install -Dm 644 %{name}-autocomplete.fish %{buildroot}%{_datadir}/fish/completions/_%{bin_name}

# Install the man pages.
mkdir -p "%{buildroot}%{_mandir}/man1"
install -D -m 0644 man/*.1 "%{buildroot}%{_mandir}/man1"

%check
./%{bin_name} -v

%files
%license LICENSE
%doc README.md

%{_bindir}/%{bin_name}
%{_mandir}/man1/%{bin_name}*.1.gz

%files bash-completion
%{_datadir}/bash-completion

%files zsh-completion
%{_datadir}/zsh

%files fish-completion
%{_datadir}/fish

%changelog
* Fri Jul 26 2024 Sai Karthik Karra <kskarthik@disroot.org>
- fix shell completions dir name
* Sat Jul 20 2024 Sai Karthik Karra <kskarthik@disroot.org>
- Add shell Completions & man pages
* Sat Jun 15 2024 Sai Karthik Karra <kskarthik@disroot.org>
  Release v0.3.1
  - Add Version flag
  - Don't Crash on Some TOTP Usage
  - Export TOTP
  - Export Skip Resource on Error
  Changelog:
    b11702d Merge pull request #48 from passbolt/fix-version
    1e09efc fix Man and Completion CI
    6cb52e2 go mod tidy
    b48f327 Use goreleaser version if available, otherwise buildinfo
    b269e85 Merge pull request #47 from passbolt/update-ci
    13da79a update Deprecated field
    effdbdb fix auto snapshot
    3cbabb9 Add dist Artifact Uploading
    eeaa987 Add Run Version Step
    c5e1dcb Update CI Action Versions
    774fc8b Merge pull request #44 from passbolt/version-flag
    4a870ea Set Version info in rootcmd
    4975d53 add versioninfo, update deps
    b3e608e Merge pull request #43 from passbolt/basic-totp-support
    e0469a1 Use old TOTP flags if the new ones are unset
    1229ad7 Implement Custom TOTP URL Generation
    869f33c remove otp library
    6f4d6e9 Add More Algorithms
    7da6aec Fix Incorrect Secret Parsing, Typos
    c595eca export: skip resource on error
    a535a83 Add TOTP Export Support
    fafdd22 update deps
    54d4243 update ci go version
    52bdc35 Update Readme about new Flags
    c2506ed Add New Flags, Mark old ones as deprecated
    2e1a46f update deps
    444fa17 Fix Doc Link
